import { useState } from "react";
import "./UserForms.Modules.css";

const RegisterForm = () => {
    const [isLogin, setIsLogin] = useState(false); // Track whether it's the login or registration form
    const [formData, setFormData] = useState({
        fullName: "",  // Single field for full name
        firstName: "",
        lastName: "",
        email: "",
        password: "",
        confirmPassword: "",
        rememberMe: false, // Initial state for "Remember Me"
    });

    const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
        const { name, value, type, checked } = e.target;
        if (type === "checkbox") {
            setFormData({
                ...formData,
                [name]: checked, // Set checkbox state
            });
        } else {
            setFormData({
                ...formData,
                [name]: value,
            });
        }
    };

    const handleSubmit = (e: React.FormEvent) => {
        e.preventDefault();

        // Split full name into first and last name
        const [firstName, ...lastNameParts] = formData.fullName.split(" ");
        const lastName = lastNameParts.join(" "); // Join the remaining parts to handle multiple last names

        // Update formData with extracted first and last names
        const updatedFormData = {
            ...formData,
            firstName: firstName || "", // Default to empty if first name is not provided
            lastName: lastName || "",   // Default to empty if last name is not provided
        };

        console.log(updatedFormData);

        // If rememberMe is true, you can save credentials to localStorage or cookies here
        if (updatedFormData.rememberMe) {
            localStorage.setItem("email", updatedFormData.email);
            localStorage.setItem("password", updatedFormData.password); // Storing password is not recommended for security reasons
        }

        // Clear form fields by resetting formData state
        setFormData({
            fullName: "",
            firstName: "",
            lastName: "",
            email: "",
            password: "",
            confirmPassword: "",
            rememberMe: false,
        });
    };

    return (
        <>
            <form onSubmit={handleSubmit} className={"form"}>
                <div className={"title"}>
                    <p>
                        {!isLogin ? (
                            <>
                                WELCOME TO NEW <strong>OPPORTUNITIES</strong>
                            </>
                        ) : (
                            <>
                                LET'S GET BACK TO <strong>APPLYING</strong>
                            </>
                        )}
                    </p>
                </div>
                <p>{isLogin ? "Sign in to your account." : "Register to get started."}</p>

                {/* Full Name Field */}
                {!isLogin && (
                    <>
                        <label htmlFor="fullName" className={"label"}>
                            Full Name
                        </label>
                        <input
                            className={"input"}
                            type="text"
                            id="fullName"
                            name="fullName"
                            placeholder="Enter your full name"
                            value={formData.fullName}
                            onChange={handleChange}
                            required
                        />
                    </>
                )}

                {/* Email Field */}
                <label htmlFor="email" className={"label"}>
                    Email
                </label>
                <input
                    className={"input"}
                    type="email"
                    id="email"
                    name="email"
                    placeholder="Enter your email"
                    value={formData.email}
                    onChange={handleChange}
                    required
                />

                {/* Password Field */}
                <label htmlFor="password" className={"label"}>
                    Password
                </label>
                <input
                    className={"input"}
                    type="password"
                    id="password"
                    name="password"
                    placeholder="Enter your password"
                    value={formData.password}
                    onChange={handleChange}
                    required
                />

                {/* Confirm Password Field (only for register) */}
                {!isLogin && (
                    <>
                        <label htmlFor="confirmPassword" className={"label"}>
                            Confirm Password
                        </label>
                        <input
                            className={"input"}
                            type="password"
                            id="confirmPassword"
                            name="confirmPassword"
                            placeholder="Confirm your password"
                            value={formData.confirmPassword}
                            onChange={handleChange}
                            required
                        />
                    </>
                )}

                {/* Submit Button */}
                <button className={"submit-button"} type="submit">
                    {isLogin ? "Sign in" : "Register now"}
                </button>

                {/* Remember Me Checkbox */}
                <div>
                    <label>
                        <input
                            type="checkbox"
                            name="rememberMe"
                            checked={formData.rememberMe}
                            onChange={handleChange}
                        />
                        Remember me
                    </label>
                </div>

                {/* Toggle between Register and Login */}
                <div className="toggle-form-link">
                    {isLogin ? (
                        <p>
                            Not a member?{" "}
                            <a href="#!" onClick={() => setIsLogin(false)}>
                                Register here
                            </a>
                        </p>
                    ) : (
                        <p>
                            Already a member?{" "}
                            <a href="#!" onClick={() => setIsLogin(true)}>
                                Sign in here
                            </a>
                        </p>
                    )}
                </div>
            </form>
        </>
    );
};

export default RegisterForm;